--- a/idlehomescreen/hscontentcontrol/inc/hscontentcontrolfactory.h Mon Mar 15 12:39:47 2010 +0200
+++ b/idlehomescreen/hscontentcontrol/inc/hscontentcontrolfactory.h Wed Mar 31 21:17:19 2010 +0300
@@ -24,11 +24,11 @@
// User includes
#include "hscontentcontrolecomobserver.h"
-#include "hscontentcontroluninstallobserver.h"
+#include "hscontentcontrolswiobserver.h"
// Forward declarations
class CHsContentControlEComListener;
-class CHsContentControlUninstallMonitor;
+class CHsContentControlSwiListener;
class CXnAppUiAdapter;
/**
@@ -44,7 +44,7 @@
*/
NONSHARABLE_CLASS( CHsContentControlFactory ) : public CBase,
public MHsContentControlEComObserver,
- public MHsContentControlUninstallObserver
+ public MHsContentControlSwiObserver
{
public: // Constructor and destructor
/**
@@ -64,14 +64,14 @@
*/
void HandleEComChangeEvent();
-private: // from MHsContentControlUninstallObserver
+private: // from MHsContentControlSwiObserver
/**
* Notification of Uninstall event from SWI.
* @param aPkgUid The package UID which is being uninstalled.
*/
- void HandleUninstallEvent( const TUid& aPkgUid );
-
+ void HandleSwiEvent( const RArray<TUid>& aUidList );
+
private: // Constructors
/**
* Constructor
@@ -150,9 +150,9 @@
CHsContentControlEComListener* iHsContentControlEComListener;
/**
* An object of type CHsContentControlUninstallMonitor ( Owned ).
*/
- CHsContentControlUninstallMonitor* iHsContentControlUninstallMonitor;
+ CHsContentControlSwiListener* iHsContentControlSwiListener;
};
@@ -64,14 +64,14 @@
/**
- * Notification of Uninstall event from SWI.
- * @param aPkgUid The package UID which is being uninstalled.
+ * Notification of Install/Uninstall event from SWI.
+ * @param aUidList The package UID list which is being processed.
*/
@@ -150,9 +150,9 @@
CHsContentControlEComListener* iHsContentControlEComListener;
/**
- * An object of type CHsContentControlUninstallMonitor ( Owned ).
+ * An object of type CHsContentControlSwiListener ( Owned ).
*/